pub type ReadValuesHandler = Arc<dyn Fn(Vec<String>) -> Pin<Box<dyn Future<Output = HashMap<String, Value>> + Send>> + Send + Sync>;Expand description
Handler function type for ReadValues messages. Called when an external client reads the current values of keys. Returns a map of key paths to their current values.
Aliased Type
pub struct ReadValuesHandler { /* private fields */ }